@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: http-api-data
 version: 0.2.2
-id: http-api-data-0.2.2-107631c0bae2e2a6211651e9a27c130c
-key: httpa_4PIMg2QbRyT0SZyC9tOKTV
+id: http-api-data-0.2.2-d85b0db99d6d5995d772ab01cd2ae49e
+key: httpa_3kiLcpdXTUe4CYRpIoinpP
 license: BSD3
 maintainer: Nickolay Kudasov <nickolay.kudasov@gmail.com>
 stability: unstable
@@ -20,11 +20,11 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/http-api-data-0.2.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/http-api-data-0.2.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/http-api-data-0.2.2
-hs-libraries: HShttp-api-data-0.2.2-4PIMg2QbRyT0SZyC9tOKTV
+hs-libraries: HShttp-api-data-0.2.2-3kiLcpdXTUe4CYRpIoinpP
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     time-locale-compat-0.1.1.1-4bbdeebce90c671369911a4d16cfee44
 haddock-interfaces: /usr/share/doc/haskell-http-api-data/html/http-api-data.haddock
